from .utils import connect_and_query
from .utils import format_produto_animale
from .utils import calculate_giro
from .utils import clean_animale_dataset
from .utils import load_provao_dataset
from .utils import label_encode_col
from .utils import reorganize_tags

from .modelling import correlation_matrix
from .modelling import distance_matrix
from .modelling import distance_sorter
from .modelling import consolidate_votes
from .modelling import count_unique_votes
from .modelling import make_model
from .modelling import search_models

from .datasets import Datasets